### Name: interaction2wt
### Title: Plot all main effects and twoway interactions in a multifactor
###   design
### Aliases: interaction2wt interaction2wt.formula interaction2wt.default
### Keywords: hplot design

### ** Examples

vulcan <- read.table(hh("datasets/vulcan.dat"), header=TRUE)
vulcan$filler <- factor(vulcan$filler)
position(vulcan$raw) <- (1:4)+.5
position(vulcan$pretreat) <- 2:4
if.R(s={old.omd=par(omd=c(.1,1,.03,1))}, r={})
if.R(r=
     interaction2wt(wear ~ filler + pretreat + raw, data=vulcan,
                    par.strip.text=list(cex=.8))
     ,s=
     interaction2wt(wear ~ filler + pretreat + raw, data=vulcan,
                    par.strip.text=list(cex=.8),
                    key.in=list(x=-3.5))
)
interaction2wt(wear ~ filler + raw, data=vulcan,
               simple=TRUE)
interaction2wt(wear ~ filler + raw, data=vulcan,
               simple=TRUE, simple.scale=c(filler=.15, raw=.2),
               xlim=c(.3, 5.6))
if.R(s={par(old.omd)}, r={})

if.R(r={
  ToothGrowth <- ToothGrowth  ## local copy
  ToothGrowth$dose <- positioned(ToothGrowth$dose) ## modify local copy
print(
  anova(aov(len ~ supp*dose, data=ToothGrowth))
)
print(
  interaction2wt(len ~ supp + dose, data=ToothGrowth)
)

esoph=esoph
esoph$rate=with(esoph, ncases/ncontrols)

position(esoph$alcgp) <- 2:5
position(esoph$tobgp) <- 2:5

print(
interaction2wt(rate ~ agegp + alcgp + tobgp, esoph, rot=c(90,0),
               par.strip.text=list(cex=.8))
)

old.cex <- trellis.par.set(par.xlab.text=list(cex=.8))
print(
interaction2wt(rate ~ agegp + alcgp + tobgp, esoph, rot=c(90,0),
               par.strip.text=list(cex=.8),
               factor.expressions=c(
                  agegp=expression(Age~~(years)),
                  alcgp=expression(Alcohol~
                                   bgroup("(",scriptstyle(frac(gm, day)),")")),
                  tobgp=expression(Tobacco~
                                   bgroup("(",scriptstyle(frac(gm,
day)),")"))),
                  responselab.expression="Cancer\nRate",
           main.in="Esophogeal Cancer Rate ~ Alcohol Consumption + Tobacco Consumption", main.cex=1.2)
)

par(old.cex)

esoph.aov <- aov(rate ~ agegp + alcgp + tobgp, data=esoph)
print(
anova(esoph.aov)
)
}, s={})



